# Changelog
All notable changes to this project will be documented in this file.


## 0.1.0 - 2022-02-04
- Initial release.
- Migrated the majority of Kordesii functionality to work with Dragodis.


[Unreleased]: https://github.com/Defense-Cyber-Crime-Center/rugosa/compare/0.1.0...HEAD
